searchNodes=[{"ref":"Sworm.html","title":"Sworm","type":"module","doc":"Sworm takes the accessible API from Swarm, and combines it with the robustness of Horde. It strives to be a combination of a global, distributed process registry and supervisor, accessible through a friendly API. Usage The concept behind Sworm is that there can be multiple, distinct &quot;sworms&quot; living inside a cluster of BEAM nodes. To define a Sworm, you define a module like this: defmodule MyProcesses do use Sworm end Now, the MyProcesses module must be added to your application&#39;s supervison tree. When you now start the application, you can use the functions from the Sworm module inside your MyProcesses module: {:ok, pid} = MyProcesses.register_name(&quot;my worker&quot;, MyWorker, :start_link, [arg1, arg2])"},{"ref":"Sworm.html#child_spec/2","title":"Sworm.child_spec/2","type":"function","doc":"Create a child specification for adding a new Sworm to the supervisor tree."},{"ref":"Sworm.html#join/3","title":"Sworm.join/3","type":"function","doc":"Joins a process to a group. Returns an error when the given process is not part of the sworm."},{"ref":"Sworm.html#leave/3","title":"Sworm.leave/3","type":"function","doc":"Removes a process from a group Returns an error when the given process is not part of the sworm."},{"ref":"Sworm.html#members/2","title":"Sworm.members/2","type":"function","doc":"Gets all the members of a group within the sworm. Returns a list of pids."},{"ref":"Sworm.html#register_name/3","title":"Sworm.register_name/3","type":"function","doc":"Registers the given name to the given process. Names registered this way will not be shifted when the cluster topology changes, and are not restarted by Sworm. If no pid is given, self() is used for the registration."},{"ref":"Sworm.html#register_name/5","title":"Sworm.register_name/5","type":"function","doc":"Register a name in the given Sworm. This function takes a module/function/args triplet, and starts the process, registers the pid with the given name, and handles cluster topology changes by restarting the process on its new node using the given MFA. Processes that are started this way are added to the Sworm&#39;s dynamic Horde supervisor, distributed over the members of the Horde according to its cluster strategy, and restarted when they crash. When the node on which the process is spawned exits, the processes are restarted on one of the other nodes in the cluster."},{"ref":"Sworm.html#registered/1","title":"Sworm.registered/1","type":"function","doc":"Gets a list of all registered names and their pids within a sworm"},{"ref":"Sworm.html#start_link/2","title":"Sworm.start_link/2","type":"function","doc":"Start and link a Sworm in a standalone fashion. You almost will never need this function, as it is more usual to start a Sworm directly in a supervisor tree, using the provided child_spec function."},{"ref":"Sworm.html#unregister_name/2","title":"Sworm.unregister_name/2","type":"function","doc":"Unregisters the given name from the sworm."},{"ref":"Sworm.html#whereis_name/2","title":"Sworm.whereis_name/2","type":"function","doc":"Get the pid of a registered name within a sworm."},{"ref":"Sworm.html#whereis_or_register_name/5","title":"Sworm.whereis_or_register_name/5","type":"function","doc":"Either finds the named process in the sworm or registers it using the register/4 function."},{"ref":"readme.html","title":"Sworm","type":"extras","doc":"Sworm A combination of a global, distributed process registry and supervisor, rolled into one, friendly API. This library aims to be a drop-in replacement for Swarm, but it is built on top of Horde."},{"ref":"readme.html#usage","title":"Sworm - Usage","type":"extras","doc":"Sworms can be defined using a macro and then added to your supervision tree. To replicate Swarm, create the following module: defmodule Swarm do use Sworm end You are not entirely done yet! Unlike the original Swarm, which has a &quot;singleton&quot; process tree, you will need to add each Sworm to your own application&#39;s supervision tree: children = [ Swarm, ... ] Now you can call Swarm.registered(), Swarm.register_name etc like you&#39;re used to. Note: handoff still needs to be implemented, see issue #1."},{"ref":"readme.html#architecture","title":"Sworm - Architecture","type":"extras","doc":"Sworm combines Horde&#39;s DynamicSupervisor and Registry modules to reproduce the Swarm library. To be able to register an aribtrary {m, f, a} specification with Sworm, it spawns a delegate process and uses this process as the primary process for name registration and supervision. This delegate process then spawns and links the actual process as specified in the MFA. This way, any MFA can be used with Sworm like it can with Swarm, and does not need to be aware of it, because the delegate process handles name registration, process shutdown on name conflicts, and, in the near future, process handoff."},{"ref":"readme.html#node-affinity-node-black-whitelisting","title":"Sworm - Node affinity / node black-/whitelisting","type":"extras","doc":"Contrarily to Swarm, Sworm does not have a black- or whitelisting mechanism. By design, each Sworm in the cluster only distributes processes among those nodes that explicitly have that particular sworm started in its supervision tree. Sworm maintains a cluster-global directory CRDT of registered Sworms, keeping track of on which node which type(s) of Sworm run. This ensures that processes are only started through Sworm on nodes that the sworm itself is also running on, instead of assuming that the cluster is homogenous and processes can run on each node, like Swarm does."},{"ref":"readme.html#process-state-handoff","title":"Sworm - Process state handoff","type":"extras","doc":"Each individual Sworm can be configured to perform state a handoff to transition the state of the process. The case here is that when a node shuts down, Sworm will move the processes running on that node onto one of the other nodes of the cluster. By default, these processes are started with a clean sheet, e.g., the state of the process is lost. But when the Sworm is configured to perform process handoffs, the processes in the sworm are given some time to hand off their state into the cluster, so that the state can be restored right after the process is started again on another node. Process handoff in Sworm works differently from the Swarm library. Process handoff must be explicitly enabled per sworm: defmodule MyProcesses do use Sworm, handoff: true end Or, in config.exs: config :sworm, MyProcesses, handoff: true When a handoff occurs, the process that is about to exit, receives the following message: {MyProcesses, :begin_handoff, delegate, ref} If it wants to pass on its internal state it needs to send the delegate a corresponding ack: send(delegate, {ref, :handoff_state, some_state}) Now, on the other node, the new process will be started in the normal way, however, right after it is started it will receive the :end_handoff signal: {MyProcesses, :end_handoff, some_state} It can then restore its state to the state that was sent by its predecessor. The most basic implementation in a genserver process of this flow is this: def handle_info({MyProcesses, :begin_handoff, delegate, ref}, state) do send(delegate, {ref, :handoff_state, state}) {:noreply, state} end def handle_info({MyProcesses, :end_handoff, state}, _state) do {:noreply, state} end"},{"ref":"readme.html#installation","title":"Sworm - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding sworm to your list of dependencies in mix.exs: def deps do [ {:sworm, &quot;~&gt; 0.1.0&quot;} ] end Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/sworm."}]